@@ -1,6 +1,6 @@
 /*
-  (C) Nelson Murilo - 2002/08/08
-  Version 0.5
+  (C) Nelson Murilo - 2003/01/31
+  Version 0.7
   C port from chkproc.pl code from Klaus Steding-Jessen <jessen@nic.br>
   and Cristine Hoepers <cristine@nic.br> +little output changes.
 
@@ -18,12 +18,16 @@
 
   2002/11/15 - Updated by Kostya Kortchinsky <kostya.kortchinsky@renater.fr>
   - ported to SunOS.
+  
+  2003/01/19 - Another Adore based lkm test. Original idea from Junichi Murakami
+ 
 */
 
 #if !defined(__linux__) && !defined(__FreeBSD__) && !defined(__sun)
 main (){ return 0; }
 #else
 #include <stdio.h>
+#include <errno.h> 
 #include <sys/types.h>
 #include <dirent.h>
 #if defined(__sun)
@@ -43,7 +47,8 @@ main (){ return 0; }
 #if defined(__sun)
 #define PS "ps -edf"
 #else
-#define PS "ps auxwww"
+#define PS "ps mauxwww 2> /dev/null"
+#define PS1 "ps auxwww"
 #endif
 
 int psproc [MAX_PROCESSES+1];
@@ -86,8 +91,13 @@ main(int argc, char **argv)
    if (!isalpha(*buf))
 #endif
    {
-     fprintf(stderr, "OooPS!\n");
-     exit(2);
+     ps  = popen(PS1, "r");
+     fgets(buf, MAX_BUF, ps); /* Skip header */
+     if (!isalpha(*buf))
+     {
+        fprintf(stderr, "OooPS!\n");
+        exit(2);
+     }
    }
    for (i = FIRST_PROCESS; i <= MAX_PROCESSES; i++) /* Init matrix */
      psproc[i] = dirproc[i] = 0;
@@ -174,6 +184,12 @@ main(int argc, char **argv)
       printf("You have % 5d process hidden for readdir command\n", retdir);
    if (retps)
       printf("You have % 5d process hidden for ps command\n", retps);
+   kill(1, 100); //  Check for SIGINVISIBLE Adore signal
+   if ( errno == 3) 
+   {
+      printf("SIGINVISIBLE Adore found\n"); 
+      retdir+= errno;
+   } 
    return (retdir+retps);
 }
 #endif
